import { CacheDelete, CacheGet, CacheIncrement, CacheSet, CacheSetIfNotExists, CacheSetFetch, CacheSetAddElements, CacheSetContainsElement, CacheSetContainsElements, CacheSetRemoveElements, CacheListFetch, CacheListLength, CacheListPushFront, CacheListPushBack, CacheListConcatenateBack, CacheListConcatenateFront, CacheListPopBack, CacheListPopFront, CacheListRemoveValue, CacheListRetain, CacheDictionarySetField, CacheDictionarySetFields, CacheDictionaryGetField, CacheDictionaryFetch, CacheDictionaryIncrement, CacheDictionaryRemoveField, CacheDictionaryRemoveFields, CacheSortedSetFetch, CacheSortedSetPutElement, CacheSortedSetPutElements, CacheSortedSetGetRank, CacheSortedSetGetScore, CacheSortedSetGetScores, CacheSortedSetIncrementScore, CacheSortedSetRemoveElement, CacheSortedSetLength, CacheSortedSetLengthByScore, CollectionTtl, SortedSetOrder, CacheItemGetType, CacheItemGetTtl, CacheKeyExists, CacheKeysExist, CacheUpdateTtl, CacheIncreaseTtl, CacheDecreaseTtl, CacheDictionaryLength, CacheDictionaryGetFields, CacheSetBatch, CacheGetBatch, CacheSetIfAbsent, CacheSetIfPresent, CacheSetIfEqual, CacheSetIfNotEqual, CacheSetIfPresentAndNotEqual, CacheSetIfAbsentOrEqual, CacheSetSample, CacheSortedSetRemoveElements, CacheSetPop, CacheSetLength } from '../../../index';
import { GetBatchCallOptions, GetCallOptions, SetBatchCallOptions, SetBatchItem, SetCallOptions, SetIfAbsentCallOptions } from '../../../utils';
export interface IDataClient {
    get(cacheName: string, key: string | Uint8Array, options?: GetCallOptions): Promise<CacheGet.Response>;
    set(cacheName: string, key: string | Uint8Array, value: string | Uint8Array, options?: SetCallOptions): Promise<CacheSet.Response>;
    delete(cacheName: string, key: string | Uint8Array): Promise<CacheDelete.Response>;
    increment(cacheName: string, field: string | Uint8Array, amount: number, ttl?: number): Promise<CacheIncrement.Response>;
    setIfNotExists(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, ttl?: number): Promise<CacheSetIfNotExists.Response>;
    setIfAbsent(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, options?: SetIfAbsentCallOptions): Promise<CacheSetIfAbsent.Response>;
    setIfPresent(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, ttl?: number): Promise<CacheSetIfPresent.Response>;
    setIfEqual(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, equal: string | Uint8Array, ttl?: number): Promise<CacheSetIfEqual.Response>;
    setIfNotEqual(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, notEqual: string | Uint8Array, ttl?: number): Promise<CacheSetIfNotEqual.Response>;
    setIfPresentAndNotEqual(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, notEqual: string | Uint8Array, ttl?: number): Promise<CacheSetIfPresentAndNotEqual.Response>;
    setIfAbsentOrEqual(cacheName: string, key: string | Uint8Array, field: string | Uint8Array, equal: string | Uint8Array, ttl?: number): Promise<CacheSetIfAbsentOrEqual.Response>;
    getBatch(cacheName: string, keys: Array<string | Uint8Array>, options?: GetBatchCallOptions): Promise<CacheGetBatch.Response>;
    setBatch(cacheName: string, items: Record<string, string | Uint8Array> | Map<string | Uint8Array, string | Uint8Array> | Array<SetBatchItem>, options?: SetBatchCallOptions): Promise<CacheSetBatch.Response>;
    setFetch(cacheName: string, setName: string): Promise<CacheSetFetch.Response>;
    setAddElements(cacheName: string, setName: string, elements: string[] | Uint8Array[], ttl?: CollectionTtl): Promise<CacheSetAddElements.Response>;
    setContainsElement(cacheName: string, setName: string, element: string | Uint8Array): Promise<CacheSetContainsElement.Response>;
    setContainsElements(cacheName: string, setName: string, elements: string[] | Uint8Array[]): Promise<CacheSetContainsElements.Response>;
    setRemoveElements(cacheName: string, setName: string, elements: string[] | Uint8Array[]): Promise<CacheSetRemoveElements.Response>;
    setSample(cacheName: string, setName: string, limit: number): Promise<CacheSetSample.Response>;
    setPop(cacheName: string, setName: string, count: number): Promise<CacheSetPop.Response>;
    setLength(cacheName: string, setName: string): Promise<CacheSetLength.Response>;
    listFetch(cacheName: string, listName: string, startIndex?: number, endIndex?: number): Promise<CacheListFetch.Response>;
    listLength(cacheName: string, listName: string): Promise<CacheListLength.Response>;
    listPushFront(cacheName: string, listName: string, value: string | Uint8Array, truncateBackToSize?: number, ttl?: CollectionTtl): Promise<CacheListPushFront.Response>;
    listPushBack(cacheName: string, listName: string, value: string | Uint8Array, truncateFrontToSize?: number, ttl?: CollectionTtl): Promise<CacheListPushBack.Response>;
    listConcatenateBack(cacheName: string, listName: string, values: string[] | Uint8Array[], truncateFrontToSize?: number, ttl?: CollectionTtl): Promise<CacheListConcatenateBack.Response>;
    listConcatenateFront(cacheName: string, listName: string, values: string[] | Uint8Array[], truncateBackToSize?: number, ttl?: CollectionTtl): Promise<CacheListConcatenateFront.Response>;
    listPopBack(cacheName: string, listName: string): Promise<CacheListPopBack.Response>;
    listPopFront(cacheName: string, listName: string): Promise<CacheListPopFront.Response>;
    listRemoveValue(cacheName: string, listName: string, value: string | Uint8Array): Promise<CacheListRemoveValue.Response>;
    listRetain(cacheName: string, listName: string, startIndex?: number, endIndex?: number, ttl?: CollectionTtl): Promise<CacheListRetain.Response>;
    dictionarySetField(cacheName: string, dictionaryName: string, field: string | Uint8Array, value: string | Uint8Array, ttl?: CollectionTtl): Promise<CacheDictionarySetField.Response>;
    dictionarySetFields(cacheName: string, dictionaryName: string, elements: Map<string | Uint8Array, string | Uint8Array> | Record<string, string | Uint8Array> | Array<[string, string | Uint8Array]>, ttl?: CollectionTtl): Promise<CacheDictionarySetFields.Response>;
    dictionaryGetField(cacheName: string, dictionaryName: string, field: string | Uint8Array): Promise<CacheDictionaryGetField.Response>;
    dictionaryGetFields(cacheName: string, dictionaryName: string, fields: string[] | Uint8Array[]): Promise<CacheDictionaryGetFields.Response>;
    dictionaryFetch(cacheName: string, dictionaryName: string): Promise<CacheDictionaryFetch.Response>;
    dictionaryIncrement(cacheName: string, dictionaryName: string, field: string | Uint8Array, amount?: number, ttl?: CollectionTtl): Promise<CacheDictionaryIncrement.Response>;
    dictionaryRemoveField(cacheName: string, dictionaryName: string, field: string | Uint8Array): Promise<CacheDictionaryRemoveField.Response>;
    dictionaryRemoveFields(cacheName: string, dictionaryName: string, fields: string[] | Uint8Array[]): Promise<CacheDictionaryRemoveFields.Response>;
    dictionaryLength(cacheName: string, dictionaryName: string): Promise<CacheDictionaryLength.Response>;
    sortedSetFetchByRank(cacheName: string, sortedSetName: string, order?: SortedSetOrder, startRank?: number, endRank?: number): Promise<CacheSortedSetFetch.Response>;
    sortedSetFetchByScore(cacheName: string, sortedSetName: string, order?: SortedSetOrder, minScore?: number, maxScore?: number, offset?: number, count?: number): Promise<CacheSortedSetFetch.Response>;
    sortedSetPutElement(cacheName: string, sortedSetName: string, value: string | Uint8Array, score: number, ttl?: CollectionTtl): Promise<CacheSortedSetPutElement.Response>;
    sortedSetPutElements(cacheName: string, sortedSetName: string, elements: Map<string | Uint8Array, number> | Record<string, number> | Array<[string, number]>, ttl?: CollectionTtl): Promise<CacheSortedSetPutElements.Response>;
    sortedSetGetRank(cacheName: string, sortedSetName: string, value: string | Uint8Array, order?: SortedSetOrder): Promise<CacheSortedSetGetRank.Response>;
    sortedSetGetScore(cacheName: string, sortedSetName: string, value: string | Uint8Array): Promise<CacheSortedSetGetScore.Response>;
    sortedSetGetScores(cacheName: string, sortedSetName: string, values: string[] | Uint8Array[]): Promise<CacheSortedSetGetScores.Response>;
    sortedSetIncrementScore(cacheName: string, sortedSetName: string, value: string | Uint8Array, amount?: number, ttl?: CollectionTtl): Promise<CacheSortedSetIncrementScore.Response>;
    sortedSetRemoveElement(cacheName: string, sortedSetName: string, value: string | Uint8Array): Promise<CacheSortedSetRemoveElement.Response>;
    sortedSetRemoveElements(cacheName: string, sortedSetName: string, values: string[] | Uint8Array[]): Promise<CacheSortedSetRemoveElements.Response>;
    sortedSetLength(cacheName: string, sortedSetName: string): Promise<CacheSortedSetLength.Response>;
    sortedSetLengthByScore(cacheName: string, sortedSetName: string, minScore?: number, maxScore?: number): Promise<CacheSortedSetLengthByScore.Response>;
    itemGetType(cacheName: string, key: string | Uint8Array): Promise<CacheItemGetType.Response>;
    itemGetTtl(cacheName: string, key: string | Uint8Array): Promise<CacheItemGetTtl.Response>;
    keyExists(cacheName: string, key: string | Uint8Array): Promise<CacheKeyExists.Response>;
    keysExist(cacheName: string, keys: string[] | Uint8Array[]): Promise<CacheKeysExist.Response>;
    updateTtl(cacheName: string, key: string | Uint8Array, ttlMilliseconds: number): Promise<CacheUpdateTtl.Response>;
    increaseTtl(cacheName: string, key: string | Uint8Array, ttlMilliseconds: number): Promise<CacheIncreaseTtl.Response>;
    decreaseTtl(cacheName: string, key: string | Uint8Array, ttlMilliseconds: number): Promise<CacheDecreaseTtl.Response>;
    close(): void;
}
