import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseSuccess } from './response-base';
import { CacheSetBatchResponse } from './enums';
import { CacheSet } from '../..';
interface IResponse {
    readonly type: CacheSetBatchResponse;
}
/**
 * Indicates a successful cache set batch request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: CacheSetBatchResponse.Success;
    private readonly body;
    constructor(body: CacheSet.Response[]);
    /**
     * Returns the status for each request in the batch as a list of CacheGet.Response objects.
     * @returns {CacheSet.Response[]}
     */
    results(): CacheSet.Response[];
}
/**
 * Indicates that an error occurred during the cache set batch request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    constructor(_innerException: SdkError);
    readonly type: CacheSetBatchResponse.Error;
}
export type Response = Success | Error;
export {};
