import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseSuccess } from './response-base';
import { CacheDictionaryIncrementResponse } from './enums';
interface IResponse {
    value(): number | undefined;
    readonly type: CacheDictionaryIncrementResponse;
}
/**
 * Indicates a Successful dictionary increment request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    private readonly _value;
    readonly type: CacheDictionaryIncrementResponse.Success;
    constructor(value: number);
    /**
     * The new value of the element after incrementing.
     * @returns {number}
     */
    value(): number;
    valueNumber(): number;
    toString(): string;
}
/**
 * Indicates that an error occurred during the dictionary increment request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheDictionaryIncrementResponse.Error;
    constructor(_innerException: SdkError);
    value(): undefined;
}
export type Response = Success | Error;
export {};
