import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseMiss, ResponseBase } from './response-base';
import { CacheDictionaryLengthResponse } from './enums';
interface IResponse {
    value(): number | undefined;
    readonly type: CacheDictionaryLengthResponse;
}
/**
 * Indicates that the requested data was successfully retrieved from the cache.  Provides
 * `value*` accessors to retrieve the data in the appropriate format.
 */
export declare class Hit extends ResponseBase implements IResponse {
    private readonly _length;
    constructor(length: number);
    /**
     * Returns the length of the dictionary
     * @returns {number}
     */
    length(): number;
    toString(): string;
    readonly type: CacheDictionaryLengthResponse.Hit;
    value(): number;
}
/**
 * Indicates that the requested data was not available in the cache.
 */
export declare class Miss extends BaseResponseMiss implements IResponse {
    readonly type: CacheDictionaryLengthResponse.Miss;
    value(): undefined;
}
/**
 * Indicates that an error occurred during the dictionary length request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    constructor(_innerException: SdkError);
    readonly type: CacheDictionaryLengthResponse.Error;
    value(): undefined;
}
export type Response = Hit | Miss | Error;
export {};
