import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseMiss, ResponseBase } from './response-base';
import { CacheItemGetTtlResponse } from './enums';
interface IResponse {
    remainingTtlMillis(): number | undefined;
    readonly type: CacheItemGetTtlResponse;
}
/**
 * Indicates a successful item get ttl request.
 */
export declare class Hit extends ResponseBase implements IResponse {
    readonly type: CacheItemGetTtlResponse.Hit;
    private readonly ttlMillis;
    constructor(itemTTLMillisRemaining: number);
    /**
     * Returns the remaining ttl in milliseconds for object stored at passed key.
     * @returns number
     */
    remainingTtlMillis(): number;
    toString(): string;
}
/**
 * Indicates that the requested item was not available in the cache.
 */
export declare class Miss extends BaseResponseMiss implements IResponse {
    readonly type: CacheItemGetTtlResponse.Miss;
    constructor();
    remainingTtlMillis(): undefined;
}
/**
 * Indicates that an error occurred during the item get ttl request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheItemGetTtlResponse.Error;
    constructor(_innerException: SdkError);
    remainingTtlMillis(): undefined;
}
export type Response = Hit | Miss | Error;
export {};
