import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseMiss, ResponseBase } from './response-base';
import { CacheItemGetTypeResponse } from './enums';
import { ItemType } from '../../utils';
interface IResponse {
    itemType(): ItemType | undefined;
    readonly type: CacheItemGetTypeResponse;
}
/**
 * Indicates a successful item get type request.
 */
export declare class Hit extends ResponseBase implements IResponse {
    readonly type: CacheItemGetTypeResponse.Hit;
    private readonly keyType;
    constructor(keyType: ItemType);
    /**
     * Returns the type of key.
     * @returns {ItemType}
     */
    itemType(): ItemType;
    toString(): string;
}
/**
 * Indicates that the requested item was not available in the cache.
 */
export declare class Miss extends BaseResponseMiss implements IResponse {
    readonly type: CacheItemGetTypeResponse.Miss;
    constructor();
    itemType(): undefined;
}
/**
 * Indicates that an error occurred during the item get type request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheItemGetTypeResponse.Error;
    constructor(_innerException: SdkError);
    itemType(): undefined;
}
export type Response = Hit | Miss | Error;
export {};
