import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseSuccess } from './response-base';
import { CacheKeyExistsResponse } from './enums';
interface IResponse {
    exists(): boolean | undefined;
    readonly type: CacheKeyExistsResponse;
}
/**
 * Indicates a successful key exists request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: CacheKeyExistsResponse.Success;
    private readonly _exists;
    constructor(exists: boolean[]);
    /**
     * Returns the boolean indicating whether the given key was found in the cache.
     * @returns {boolean}
     */
    exists(): boolean;
    toString(): string;
}
/**
 * Indicates that an error occurred during the key exists request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheKeyExistsResponse.Error;
    constructor(_innerException: SdkError);
    exists(): undefined;
}
export type Response = Success | Error;
export {};
