import { SdkError } from '../../errors';
import { BaseResponseError, BaseResponseMiss, ResponseBase } from './response-base';
import { CacheListLengthResponse } from './enums';
interface IResponse {
    value(): number | undefined;
    readonly type: CacheListLengthResponse;
}
/**
 * Indicates that the requested list was successfully retrieved from the cache.
 * Provides `value` and `length` accessors to retrieve the length of the list.
 */
export declare class Hit extends ResponseBase implements IResponse {
    readonly type: CacheListLengthResponse.Hit;
    private readonly _length;
    constructor(length: number);
    /**
     * Returns the length of the list.
     * @returns number
     */
    value(): number;
    /**
     * Returns the length of the list.
     * @returns number
     */
    length(): number;
    toString(): string;
}
/**
 * Indicates that the requested list was not available in the cache.
 */
export declare class Miss extends BaseResponseMiss implements IResponse {
    readonly type: CacheListLengthResponse.Miss;
    constructor();
    value(): undefined;
}
/**
 * Indicates that an error occurred during the list length request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheListLengthResponse.Error;
    constructor(_innerException: SdkError);
    value(): undefined;
}
export type Response = Hit | Miss | Error;
export {};
