import { ResponseBase, BaseResponseError, BaseResponseMiss } from './response-base';
import { CacheSortedSetGetRankResponse } from './enums';
import { SdkError } from '../../errors';
interface IResponse {
    rank(): number | undefined;
    readonly type: CacheSortedSetGetRankResponse;
}
/**
 * Indicates that the requested data was successfully retrieved from the cache.  Provides
 * `rank()` accessor to retrieve rank.
 */
export declare class Hit extends ResponseBase implements IResponse {
    private readonly _rank;
    readonly type: CacheSortedSetGetRankResponse.Hit;
    constructor(rank: number);
    /**
     * Returns the rank of the element in the sorted set.  Ranks start at 0.
     * @returns {number}
     */
    rank(): number;
    toString(): string;
}
/**
 * Indicates that the requested data was not available in the cache.
 */
export declare class Miss extends BaseResponseMiss implements IResponse {
    readonly type: CacheSortedSetGetRankResponse.Miss;
    constructor();
    rank(): undefined;
}
/**
 * Indicates that an error occurred during the sorted set get rank request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheSortedSetGetRankResponse.Error;
    constructor(error: SdkError);
    rank(): undefined;
}
export type Response = Hit | Miss | Error;
export {};
