import { BaseResponseError, BaseResponseSuccess } from './response-base';
import { CacheSortedSetIncrementScoreResponse } from './enums';
import { SdkError } from '../../errors';
interface IResponse {
    score(): number | undefined;
    readonly type: CacheSortedSetIncrementScoreResponse;
}
/**
 * Indicates a Successful sorted set IncrementScore request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    private readonly _score;
    readonly type: CacheSortedSetIncrementScoreResponse.Success;
    constructor(score: number);
    /**
     * The new score of the element after incrementing.
     * @returns {number}
     */
    score(): number;
    toString(): string;
}
/**
 * Indicates that an error occurred during the sorted set IncrementScore request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: CacheSortedSetIncrementScoreResponse.Error;
    constructor(error: SdkError);
    score(): undefined;
}
export type Response = Success | Error;
export {};
