import { SdkError } from '../../../errors';
import { BaseResponseError, BaseResponseSuccess } from '../response-base';
import { LeaderboardLengthResponse } from '../enums';
interface IResponse {
    readonly type: LeaderboardLengthResponse;
}
/**
 * Indicates a successful leaderboard length request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: LeaderboardLengthResponse.Success;
    private readonly _length;
    constructor(length: number);
    /**
     * Returns the length of the leaderboard
     * @returns {number}
     */
    length(): number;
    toString(): string;
}
/**
 * Indicates that an error occurred during the leaderboard length request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: LeaderboardLengthResponse.Error;
    constructor(_innerException: SdkError);
}
export type Response = Success | Error;
export {};
