import { BaseResponseSuccess, BaseResponseError } from './response-base';
import { RefreshApiKeyResponse } from './enums';
import { SdkError } from '../../errors';
import { ExpiresAt } from '../../utils';
interface IResponse {
    readonly type: RefreshApiKeyResponse;
}
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: RefreshApiKeyResponse.Success;
    readonly apiKey: string;
    readonly refreshToken: string;
    readonly endpoint: string;
    readonly expiresAt: ExpiresAt;
    /**
     * @deprecated Use `apiKey` instead.
     * @returns {string}
     */
    get authToken(): string;
    constructor(apiKey: string, refreshToken: string, endpoint: string, expiresAt: ExpiresAt);
}
/**
 * Indicates that an error occurred during the generate api token request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    constructor(innerException: SdkError);
    readonly type: RefreshApiKeyResponse.Error;
}
export type Response = Success | Error;
export {};
