import { CreateStoreResponse } from '../../enums';
import { BaseResponseError, BaseResponseSuccess } from '../../response-base';
import { SdkError } from '../../../../errors';
interface IResponse {
    readonly type: CreateStoreResponse;
}
/**
 * Indicates a successful create store request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: CreateStoreResponse.Success;
}
/**
 * Indicates that the store already exists.
 */
export declare class AlreadyExists extends BaseResponseSuccess implements IResponse {
    readonly type: CreateStoreResponse.AlreadyExists;
}
/**
 * Indicates that an error occurred during the create store request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    constructor(_innerException: SdkError);
    readonly type: CreateStoreResponse.Error;
}
export type Response = Success | AlreadyExists | Error;
export {};
