import { SdkError } from '../../../errors';
import { BaseResponseError, BaseResponseSuccess } from '../response-base';
import { GetWebhookSecretResponse } from '../enums';
interface IResponse {
    readonly type: GetWebhookSecretResponse;
}
type Props = {
    secret: string;
    cacheName: string;
    webhookName: string;
};
/**
 * Indicates a Successful GetWebhookSecret request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    readonly type: GetWebhookSecretResponse.Success;
    private readonly _secret;
    private readonly _webhookName;
    private readonly _cacheName;
    constructor(props: Props);
    secret(): string;
    webhookName(): string;
    cacheName(): string;
    toString(): string;
}
/**
 * Indicates that an error occurred during the GetWebhookSecret request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: GetWebhookSecretResponse.Error;
    constructor(_innerException: SdkError);
}
export type Response = Success | Error;
export {};
