import { SdkError } from '../../../errors';
import { BaseResponseError, BaseResponseSuccess } from '../response-base';
import { Webhook } from '../../webhook';
import { ListWebhooksResponse } from '../enums';
interface IResponse {
    readonly type: ListWebhooksResponse;
}
/**
 * Indicates a Successful list webhooks request.
 */
export declare class Success extends BaseResponseSuccess implements IResponse {
    private readonly webhooks;
    readonly type = ListWebhooksResponse.Success;
    constructor(webhooks: Webhook[]);
    /**
     * An array of webhooks.
     * @returns {Webhook[]}
     */
    getWebhooks(): Webhook[];
    toString(): string;
}
/**
 * Indicates that an error occurred during the list webhooks request.
 *
 * This response object includes the following fields that you can use to determine
 * how you would like to handle the error:
 *
 * - `errorCode()` - a unique Momento error code indicating the type of error that occurred.
 * - `message()` - a human-readable description of the error
 * - `innerException()` - the original error that caused the failure; can be re-thrown.
 */
export declare class Error extends BaseResponseError implements IResponse {
    readonly type: ListWebhooksResponse.Error;
    constructor(_innerException: SdkError);
}
export type Response = Success | Error;
export {};
